"""
Provides systembridgewindowssensors version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update systembridgewindowssensors` to change this file.

from incremental import Version

__version__ = Version("systembridgewindowssensors", 3, 1, 2, dev=4)
__all__ = ["__version__"]
